==> 3.25.0.tar.gz: 3.25.0/doc/content/docs/60iam/permission.md <==
---
title: IAM - Permissions
description: Reference
weight: 330
---

**Permissions** are atomic authorization units that control access to specific features and data operations in Cavaliba.

## p_admin

Universal administrator permission. Grants full access to all system features and data regardless of other role or permission constraints. Use with caution - assign only to trusted administrators.

## p_admintools

Admin tools access

## p_conf_admin

Configuration admin permission

## p_conf_view

Configuration view permission

## p_data_access

Data dashboard access

## p_data_admin

Data admin (all permissions, non-blocking)

## p_data_app_admin

App admin permission

## p_data_app_create

App create permission

## p_data_app_delete

App delete permission

## p_data_app_read

App read permission

## p_data_app_update

App update permission

## p_data_create

Data create all

## p_data_delete

Data delete all

## p_data_export

Data export tool

## p_data_export_viewer

Data export tool (viewer)

## p_data_import

Data import tool

## p_data_read

Data read all

## p_data_security_edit

Data security edit permission

## p_data_security_view

Data security view permission

## p_data_site_admin

Site admin permission

## p_data_site_create

Site create permission

## p_data_site_delete

Site delete permission

## p_data_site_read

Site read permission

## p_data_site_update

Site update permission

## p_data_sitegroup_admin

Site group admin permission

## p_data_sitegroup_create

Site group create permission

## p_data_sitegroup_delete

Site group delete permission

## p_data_sitegroup_read

Site group read permission

## p_data_sitegroup_update

Site group update permission

## p_data_sirene_message_admin

Sirene message admin permission

## p_data_sirene_message_create

Sirene message create permission

## p_data_sirene_message_delete

Sirene message delete permission

## p_data_sirene_message_read

Sirene message read permission

## p_data_sirene_message_update

Sirene message update permission

## p_data_sirene_public_admin

Sirene public admin permission

## p_data_sirene_public_create

Sirene public create permission

## p_data_sirene_public_delete

Sirene public delete permission

## p_data_sirene_public_read

Sirene public read permission

## p_data_sirene_public_update

Sirene public update permission

## p_data_sirene_template_admin

Sirene template admin permission

## p_data_sirene_template_create

Sirene template create permission

## p_data_sirene_template_delete

Sirene template delete permission

## p_data_sirene_template_read

Sirene template read permission

## p_data_sirene_template_update

Sirene template update permission

## p_data_update

Data update all

## p_dataview_admin

Data view admin permission

## p_dataview_create

Data view create permission

## p_dataview_delete

Data view delete permission

## p_dataview_read

Data view read permission

## p_dataview_update

Data view update permission

## p_enumerate_admin

Enumerate admin permission

## p_enumerate_create

Enumerate create permission

## p_enumerate_delete

Enumerate delete permission

## p_enumerate_read

Enumerate read permission

## p_enumerate_update

Enumerate update permission

## p_home_access

Home app access

## p_home_admin

Home dashboard admin

## p_iam_access

IAM access

## p_iam_export

IAM export permission

## p_iam_impersonate

Can impersonate other accounts

## p_info

Get Version/Info permission

## p_ipam_access

IPAM access

## p_ipam_admin

IPAM admin permission

## p_ipam_read

IPAM read permission

## p_ipam_write

IPAM write permission

## p_log_admin

Log admin permission

## p_log_view

Log view permission

## p_permission_create

Permission create permission

## p_permission_delete

Permission delete permission

## p_permission_read

Permission read permission

## p_permission_update

Permission update permission

## p_pipeline_admin

Pipeline admin permission

## p_pipeline_create

Pipeline create permission

## p_pipeline_delete

Pipeline delete permission

## p_pipeline_read

Pipeline read permission

## p_pipeline_update

Pipeline update permission

## p_role_create

Role create permission

## p_role_delete

Role delete permission

## p_role_read

Role read permission

## p_role_update

Role update permission

## p_schema_create

Schema create permission

## p_schema_delete

Schema delete permission

## p_schema_read

Schema read permission

## p_schema_update

Schema update permission

## p_schemafield_create

Schema field create permission

## p_schemafield_delete

Schema field delete permission

## p_schemafield_read

Schema field read permission

## p_schemafield_update

Schema field update permission

## p_sirene_access

Sirene app access

## p_sirene_access_restricted

Access to restricted messages

## p_sirene_archive

Archive notification

## p_sirene_detail

Access message details

## p_sirene_flushall

Archive all active notifications

## p_sirene_history

Access message history

## p_sirene_new

Create new notification

## p_sirene_sms_journal

SMS journal access

## p_sirene_sms_send

Send SMS

## p_sirene_sms_stat

SMS statistics

## p_sirene_update

Update notification

## p_status_access

Status app access

## p_status_admin

Status admin permission

## p_status_read

Status read permission

## p_status_write

Status write permission

## p_user_create

User create permission

## p_user_debug

Debug permission

## p_user_delete

User delete permission

## p_user_email_test

Test email permission

## p_user_pref

User preferences permission

## p_user_read

User read permission

## p_user_sms_test

Test SMS permission

## p_user_update

User update permission

## p_apikey_admin

API key admin permission

## p_apikey_create

API key create permission

## p_apikey_delete

API key delete permission

## p_apikey_read

API key read permission

## p_apikey_update

API key update permission

## p_group_create

Group create permission

## p_group_delete

Group delete permission

## p_group_read

Group read permission

## p_group_update

Group update permission

==> 3.27.6.tar.gz: 3.27.6/doc/content/docs/60iam/permission.md <==
---
title: IAM - Permissions
description: Reference
weight: 330
---

**Permissions** are atomic authorization units that control access to specific features and data operations in Cavaliba.




# Admin

## p_admin

Universal administrator permission. Grants full access to all system features and data regardless of other role or permission constraints. Use with caution - assign only to trusted administrators.

## p_admintools

Admin tools access from UI




# Conf

## p_conf_admin

Configuration admin permission

## p_conf_view

Configuration view permission




# Logs

## p_log_admin

Log admin permission

## p_log_view

Log view permission



## p_info

Get Version/Info permission





# Home/Dashboard

## p_home_access

Home app access

## p_home_admin

Home dashboard admin





# Schemas

## p_schema_read

Can read all schemas and field definitions


## p_schema_write

Can create, update, enable, disable, and delete all schemas and fields definitions.






# Data Instances

## p_data_access

Data dashboard access

## p_data_admin

Data admin (all permissions, non-blocking) on all Data Instance


## p_data_read

Data read all. Can be blocker at instance level.

## p_data_create

Data create all. Can be blocker at instance level.

## p_data_delete

Data delete all. Can be blocker at instance level.

## p_data_update

Data update all. Can be blocker at instance level.

## p_data_export

Data export tool. Can be blocker at instance level.

## p_data_import

Data import tool. Can be blocker at instance level.

## p_data_export_viewer

Data export tool (viewer)



## p_data_security_edit

Data security edit permission

## p_data_security_view

Data security view permission






# Dataview


## p_dataview_admin

Data view admin permission

## p_dataview_create

Data view create permission

## p_dataview_delete

Data view delete permission

## p_dataview_read

Data view read permission

## p_dataview_update

Data view update permission





# Enumerate

## p_enumerate_admin

Enumerate admin permission

## p_enumerate_create

Enumerate create permission

## p_enumerate_delete

Enumerate delete permission

## p_enumerate_read

Enumerate read permission

## p_enumerate_update

Enumerate update permission










# Pipelines

## p_pipeline_admin

Pipeline admin permission

## p_pipeline_create

Pipeline create permission

## p_pipeline_delete

Pipeline delete permission

## p_pipeline_read

Pipeline read permission

## p_pipeline_update

Pipeline update permission



# IAM - Common

## p_iam_access

IAM access

## p_iam_export

IAM export permission

## p_iam_impersonate

Can impersonate other accounts





# IAM - User

## p_user_create

User create permission

## p_user_debug

Debug permission

## p_user_delete

User delete permission

## p_user_email_test

Test email permission

## p_user_pref

User preferences permission

## p_user_read

User read permission

## p_user_sms_test

Test SMS permission

## p_user_update

User update permission




# IAM - Groups

## p_group_create

Group create permission

## p_group_delete

Group delete permission

## p_group_read

Group read permission

## p_group_update

Group update permission




# IAM - Permissions


## p_permission_create

Permission create permission

## p_permission_delete

Permission delete permission

## p_permission_read

Permission read permission

## p_permission_update

Permission update permission




# IAM - ApiKeys

## p_apikey_admin

API key admin permission

## p_apikey_create

API key create permission

## p_apikey_delete

API key delete permission

## p_apikey_read

API key read permission

## p_apikey_update

API key update permission





# IAM - Roles

## p_role_create

Role create permission

## p_role_delete

Role delete permission

## p_role_read

Role read permission

## p_role_update

Role update permission





# Specific *app* instances

This schema is created for various Applications in Cavaliba (Sirene Notify).


## p_data_app_admin

App admin permission

## p_data_app_create

App create permission

## p_data_app_delete

App delete permission

## p_data_app_read

App read permission

## p_data_app_update

App update permission




# Specific *site* instances

This schema is created for various Applications in Cavaliba (Sirene Notify).



## p_data_site_admin

Site admin permission

## p_data_site_create

Site create permission

## p_data_site_delete

Site delete permission

## p_data_site_read

Site read permission

## p_data_site_update

Site update permission



# Specific *sitegroup* instances

This schema is created for various Applications in Cavaliba (Sirene Notify).


## p_data_sitegroup_admin

Site group admin permission

## p_data_sitegroup_create

Site group create permission

## p_data_sitegroup_delete

Site group delete permission

## p_data_sitegroup_read

Site group read permission

## p_data_sitegroup_update

Site group update permission




# Specific *sirene_message* intsances

This schema is created for various Applications in Cavaliba (Sirene Notify).


## p_data_sirene_message_admin

Sirene message admin permission

## p_data_sirene_message_create

Sirene message create permission

## p_data_sirene_message_delete

Sirene message delete permission

## p_data_sirene_message_read

Sirene message read permission

## p_data_sirene_message_update

Sirene message update permission





# Specific *sirene_public* intsances

This schema is created for various Applications in Cavaliba (Sirene Notify).


## p_data_sirene_public_admin

Sirene public admin permission

## p_data_sirene_public_create

Sirene public create permission

## p_data_sirene_public_delete

Sirene public delete permission

## p_data_sirene_public_read

Sirene public read permission

## p_data_sirene_public_update

Sirene public update permission




# Specific *sirene_template* intsances

This schema is created for various Applications in Cavaliba (Sirene Notify).


## p_data_sirene_template_admin

Sirene template admin permission

## p_data_sirene_template_create

Sirene template create permission

## p_data_sirene_template_delete

Sirene template delete permission

## p_data_sirene_template_read

Sirene template read permission

## p_data_sirene_template_update

Sirene template update permission




#  APP - Sirene/Notify

## p_sirene_access

Sirene app access

## p_sirene_access_restricted

Access to restricted messages

## p_sirene_archive

Archive notification

## p_sirene_detail

Access message details

## p_sirene_flushall

Archive all active notifications

## p_sirene_history

Access message history

## p_sirene_new

Create new notification

## p_sirene_sms_journal

SMS journal access

## p_sirene_sms_send

Send SMS

## p_sirene_sms_stat

SMS statistics

## p_sirene_update

Update notification





# APP - Status Page

## p_status_access

Status app access

## p_status_admin

Status admin permission

## p_status_read

Status read permission

## p_status_write

Status write permission



# APP - IPAM IP Address Management

## p_ipam_access

IPAM access

## p_ipam_admin

IPAM admin permission

## p_ipam_read

IPAM read permission

## p_ipam_write

IPAM write permission
